# cevlib
inofficial python library for cev.eu (NOT affiliated)

## Terms of Use
please refer to [cev.eu's Terms of Use](https://www.cev.eu/terms-of-use/)

The Owner undertakes its utmost effort to ensure that the content provided in this Application infringes no applicable legal provisions or third-party rights. However, it may not always be possible to achieve such a result.
In such cases, without prejudice to any legal prerogatives of Users to enforce their rights, Users are kindly asked to preferably report related complaints by opening an issue.

## Install
```sh
pip install cevlib
```

## Live Demo
[CEV Next](https://cev-next.herokuapp.com/#/) makes use of exactly this library and displays the available information in a beautiful UI.

## [Try it out](https://cev-next.herokuapp.com/#/cevlib/wiki)

## [Quick Start](https://github.com/dxstiny/cevlib/wiki)

## Contact
In case of legal complaints or other comments, you can contact me (the owner of this repository) via email: info@cev-nex.tk
